==> babel-plugin-namespace-0.0.2.tgz: package/README.md <==
# babel-plugin-namespace [![Build Status][travis-image]][travis-url]

A [babel](http://babeljs.io) plugin to enable namespacing and rewrite these namespace as an alias for directories as different directories during the Babel process.

## Description

Instead of using relative paths in your project, you'll be able to use a namespace. Here an simple example:

**Be Carefull:** This plugin also work with `require()` function.

## Installation

Install the plugin

```
$ npm install -D babel-plugin-namespace
```

Specify the plugin in your `.babelrc` with the custom mapping.
```json
{
  "plugins": [
    ["namespace", {
      "sources": [
        "sources/directory",
        "maybe/we/have/lib"
      ],
      "includes": [
        "app",
        "lib"
      ],
      "excludes": [
        "node_modules"
      ],
      "namespaces": {
        "test": "tests",
        "foo/bar/baz": "path/to/foo/bar/baz",
      }
    }]
  ]
}
```

If you're using [eslint-plugin-import][eslint-plugin-import], you should use [eslint-import-resolver-babel-namespace][eslint-babel-namespace] to avoid having false errors.

## Usage

Given the directory structure:

```
/root
  .babelrc
  /foo
    /bar
      baz.js
  /src
    /models
      User.js
    /controllers
      User.js
  package.json
```

**In package.json:**

*The most important things in your package.json is the name field*

```json
{
  "name": ["my-package-name"]
}
```

**In .babelrc:**

```json
{
  "presets": ["es2015"],
  "plugins": [
    "namespace"
  ]
}
```

**In src/controllers/User.js:**

```javascript
// Instead of using this;
import UserModel from '../models/User';
// Use that:
import UserModel from 'my-package-name/models/User';
// => resolves: '../models/User.js';
// NOTE: "my-package-name" is come from your package.json
```

```javascript
// Instead of using this;
import baz from '../../foo/bar/baz';
// Use that:
import baz from 'my-package-name/foo/bar/baz';
// => resolves: '../../foo/bar/baz.js';
// NOTE: "foo" directory is auto generated, because we are not provide any options to the plugin
```

## License

MIT, see [LICENSE](LICENSE) for details.

[travis-image]: https://travis-ci.org/yudhasetiawan/babel-plugin-namespace.svg?branch=master
[travis-url]: https://travis-ci.org/yudhasetiawan/babel-plugin-namespace
[eslint-babel-namespace]: https://github.com/yudhasetiawan/eslint-import-resolver-babel-namespace
[eslint-plugin-import]: https://github.com/benmosher/eslint-plugin-import

==> babel-plugin-namespace-0.0.3.tgz: package/README.md <==
# babel-plugin-namespace [![Build Status][travis-image]][travis-url]

A [babel](http://babeljs.io) plugin to enable namespacing and rewrite these namespace as an alias for directories as different directories during the Babel process.

## Description

Instead of using relative paths in your project, you'll be able to use a namespace. Here an simple example:

**Be Carefull:** This plugin also work with `require()` function.

## Installation

Install the plugin

```
$ npm install -D babel-plugin-namespace
```

Specify the plugin in your `.babelrc` with the custom mapping.
```json
{
  "plugins": [
    ["namespace", {
      "sources": [
        "src"
      ],
      "includes": [
        "foo""
      ],
      "excludes": [
        "node_modules"
      ],
      "namespaces": {
        "test": "tests",
        "foo/bar/baz": "path/to/foo/bar/baz",
      }
    }]
  ]
}
```

If you're using [eslint-plugin-import][eslint-plugin-import], you should use [eslint-import-resolver-babel-namespace][eslint-babel-namespace] to avoid having false errors.

## Usage

Given the directory structure:

```
/root
  .babelrc
  /foo
    /bar
      baz.js
  /src
    /models
      User.js
    /controllers
      User.js
  package.json
```

**In package.json:**

*The most important things in your package.json is the name field*

```json
{
  "name": ["my-package-name"]
}
```

**In .babelrc:**

```json
{
  "presets": ["es2015"],
  "plugins": [
    "namespace"
  ]
}
```

**In src/controllers/User.js:**

```javascript
// Instead of using this;
import UserModel from '../models/User';
// Use that:
import UserModel from 'my-package-name/models/User';
// => resolves: '../models/User.js';
// NOTE: "my-package-name" is come from your package.json
```

```javascript
// Instead of using this;
import baz from '../../foo/bar/baz';
// Use that:
import baz from 'my-package-name/foo/bar/baz';
// => resolves: '../../foo/bar/baz.js';
// NOTE: "foo" directory is created by "includes" field from our configuration
```

## License

MIT, see [LICENSE](LICENSE) for details.

[travis-image]: https://travis-ci.org/yudhasetiawan/babel-plugin-namespace.svg?branch=master
[travis-url]: https://travis-ci.org/yudhasetiawan/babel-plugin-namespace
[eslint-babel-namespace]: https://github.com/yudhasetiawan/eslint-import-resolver-babel-namespace
[eslint-plugin-import]: https://github.com/benmosher/eslint-plugin-import
